==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Offset</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">Distance :</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Nombre :</translation>
    </message>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Choisissez une ligne, arc ou cercle</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Para&amp;llèle (avec la distance)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Decaler (distance)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Décalage ligne, arc, cercle ou ellipse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Dessinez une parallèle à une ligne existante ou un arc ou cercle concentriques</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Distance :</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Nombre :</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Choisissez ligne, arc, cercle ou ellipse</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Choisissez ligne, arc, cercle ou ellipse</translation>
    </message>
    <message>
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation>Rayon chuté en dessous de zéro après %1 cercle(s) concentrique(s).</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation>Rayon chuté en dessous de zéro, après %1 arc(s) concentrique(s).</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Offset</name>
    <message>
        <source>Distance:</source>
        <translation type="obsolete">Distance :</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation type="obsolete">Nombre :</translation>
    </message>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">Choisissez une ligne, arc ou cercle</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">Para&amp;llèle (avec la distance)</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>Decaler (distance)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>Décalage ligne, arc, cercle ou ellipse</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">Dessinez une parallèle à une ligne existante ou un arc ou cercle concentriques</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;Distance :</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;Nombre :</translation>
    </message>
    <message>
        <source>Choose line, arc, circle, ellipse or spline</source>
        <translation type="vanished">Choisissez ligne, arc, cercle ou ellipse</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Choisissez ligne, arc, cercle ou ellipse</translation>
    </message>
    <message numerus="yes">
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %n concentric circle(s).</source>
        <translation>
            <numerusform>Rayon chuté en dessous de zéro après %n cercle concentrique.</numerusform>
            <numerusform>Rayon chuté en dessous de zéro après %n cercles concentriques.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %n concentric arc(s).</source>
        <translation>
            <numerusform>Rayon chuté en dessous de zéro, après %n arc concentrique.</numerusform>
            <numerusform>Rayon chuté en dessous de zéro, après %n arcs concentriques.</numerusform>
        </translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Rayon chuté en dessous de zéro après %1 cercle(s) concentrique(s).</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Rayon chuté en dessous de zéro, après %1 arc(s) concentrique(s).</translation>
    </message>
</context>
</TS>
